@@ -3,11 +3,11 @@
 # Copyright (c) 2016 Felix Krull <f_krull@gmx.de>
 # Released under the terms of the BSD license; see LICENSE.
 
-from unittest import TestCase
+import unittest
 
 
-class TestModuleImport(TestCase):
-    def assertImports(self, modname):  # noqa
+class TestModuleImport(unittest.TestCase):
+    def assertImports(self, modname):
         try:
             __import__(modname)
         except ImportError as exc:
@@ -27,3 +27,7 @@ class TestModuleImport(TestCase):
 
     def test_ext_html_compat(self):
         self.assertImports('quark_sphinx_theme.ext.html_compat')
+
+
+if __name__ == '__main__':
+    unittest.main()
