@@ -19,11 +19,19 @@ except ImportError:
     from io import StringIO
 
 import html5lib
-import sphinx
 try:
     import tinycss
 except ImportError:
     tinycss = None
+try:
+    from sphinx.cmd.build import main
+except ImportError:
+    from sphinx import main as _main
+    def main(args):
+        main_args = ['sphinx_build']
+        main_args.extend(args)
+        return _main(main_args)
+
 
 
 @contextmanager
@@ -65,9 +73,8 @@ def get_css_errors(filename_or_fobj, encoding=None):
     return errors
 
 
-def run_sphinx(source_dir, build_dir, builder='html', extra_config={}, tags=[],
-               sphinx_build='sphinx-build'):
-    args = ['sphinx_build', '-b', builder, '-N']
+def run_sphinx(source_dir, build_dir, builder='html', extra_config={}, tags=[]):
+    args = ['-b', builder, '-N']
     for k, v in extra_config.items():
         args.extend(['-D', '%s=%s' % (k, v)])
     for tag in tags:
@@ -75,7 +82,7 @@ def run_sphinx(source_dir, build_dir, builder='html', extra_config={}, tags=[],
     args.extend([source_dir, build_dir])
     with capture_output() as stdout:
         try:
-            ret = sphinx.main(args)
+            ret = main(args)
         except SystemExit as e:
             ret = e.code
         if ret != 0:
